package com.ruoyi.project.production.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS1301;

/**
 * 质量月报S1301Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface TMonthlyQualityReportS1301Mapper 
{
    /**
     * 查询质量月报S1301
     * 
     * @param id 质量月报S1301ID
     * @return 质量月报S1301
     */
    public TMonthlyQualityReportS1301 selectTMonthlyQualityReportS1301ById(Long id);

    /**
     * 查询质量月报S1301列表
     * 
     * @param tMonthlyQualityReportS1301 质量月报S1301
     * @return 质量月报S1301集合
     */
    @DataScope(deptAlias = "d")
    public List<TMonthlyQualityReportS1301> selectTMonthlyQualityReportS1301List(TMonthlyQualityReportS1301 tMonthlyQualityReportS1301);

    /**
     * 新增质量月报S1301
     * 
     * @param tMonthlyQualityReportS1301 质量月报S1301
     * @return 结果
     */
    public int insertTMonthlyQualityReportS1301(TMonthlyQualityReportS1301 tMonthlyQualityReportS1301);

    /**
     * 修改质量月报S1301
     * 
     * @param tMonthlyQualityReportS1301 质量月报S1301
     * @return 结果
     */
    public int updateTMonthlyQualityReportS1301(TMonthlyQualityReportS1301 tMonthlyQualityReportS1301);

    /**
     * 删除质量月报S1301
     * 
     * @param id 质量月报S1301ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS1301ById(Long id);

    /**
     * 批量删除质量月报S1301
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS1301ByIds(Long[] ids);
}
